
-- Default Config Values
ShotGlassSavedSettings = ShotGlassSavedSettings or {}
ShotGlassSavedAuras = ShotGlassSavedAuras or {}

ShotGlassDefaultSettings = {
	ShowDraggingHandle = true,		
	ShowSolo = true,				
	--ShowPlayer = true,				
	--Defaultscale = 1,				
	MirrorRow = false,				-- SetAttribute("point", "LEFT")
	--MirrorColumn = false,			-- SetAttribute("columnAnchorPoint", "TOP")
	--ExpirationAlert = true,
}

local function CreateCheckButton( reference, parent, label)
	local checkbutton = CreateFrame( "CheckButton", reference, parent, "InterfaceOptionsCheckButtonTemplate" )
	_G[reference.."Text"]:SetText(label)
	checkbutton.GetValue = function() if checkbutton:GetChecked() then return true else return false end end
	checkbutton.SetValue = checkbutton.SetChecked

	return checkbutton
end

local function ToggleDraggingHandle(show)
	if show == false then ShotGlassRaidFrames.HandleFrame:Hide() 
	else ShotGlassRaidFrames.HandleFrame:Show() end
end

local function ApplyConfiguration()
	
	ToggleDraggingHandle(ShotGlassSavedSettings.ShowDraggingHandle)
	ShotGlassRaidFrames:SetAttribute("showSolo", ShotGlassSavedSettings.ShowSolo)
	--if ShotGlassSavedSettings.MirrorRow then ShotGlassRaidFrames:SetAttribute("point", "RIGHT") else
	--	ShotGlassRaidFrames:SetAttribute("point", "LEFT") end

end

local function ResetPosition()
	print("Resetting Shot Glass position...")
	ShotGlassRaidFrames:ClearAllPoints()
	ShotGlassRaidFrames:SetPoint("CENTER", UIParent)
end

local function AddAuras()
	for i,v in pairs(ShotGlassSavedAuras) do
		TrackedAuras[i] = {position = v.position, color = v.color,}
	end
end


local function CreateInterfacePanel( objectName, panelTitle)
	
	-- Panel
	------------------------------
	local panel = CreateFrame( "Frame", objectName.."_InterfaceOptionsPanel", UIParent);

	-- controls
	local controls = {}
	
	local function GetPanelValues()
		for i,v in pairs(controls) do
			if v.GetValue then ShotGlassSavedSettings[i] = v:GetValue() end
		end
		ApplyConfiguration()
	end
	
	local function SetPanelValues()
		for i,v in pairs(controls) do
			if v.SetValue then v:SetValue(ShotGlassSavedSettings[i]) end
		end
	end
	
	panel.name = panelTitle
	panel.okay = GetPanelValues
	panel.refresh = SetPanelValues
	
	panel:SetScript("OnEvent", function(self, event)
		if event == "PLAYER_ENTERING_WORLD" then
			AddAuras()
		
			ShotGlassSavedSettings = ShotGlassSavedSettings or {}
			for i,v in pairs(ShotGlassDefaultSettings) do
				ShotGlassSavedSettings[i] = ShotGlassSavedSettings[i] or ShotGlassDefaultSettings[i]
			end
		end
		
	end)
	panel:RegisterEvent("PLAYER_ENTERING_WORLD")

	local version = GetAddOnMetadata("ShotGlass", "version")
	
	panel.MainLabel = panel:CreateFontString(nil, 'ARTWORK', 'GameFontNormalLarge')
	panel.MainLabel:SetPoint("TOP", panel, "TOP", 0, -16)
	panel.MainLabel:SetPoint("LEFT", panel, "LEFT", 16, 0)
	panel.MainLabel:SetHeight(15)
	panel.MainLabel:SetWidth(350)
	panel.MainLabel:SetJustifyH("LEFT")
	panel.MainLabel:SetJustifyV("TOP")
	panel.MainLabel:SetText(panelTitle.." "..version)
	
	controls.ShowDraggingHandle = CreateCheckButton(objectName.."ShowDraggingHandle", panel, "Show the Drag Handle")
	controls.ShowDraggingHandle:SetPoint("TOP", panel.MainLabel, "TOP", 0, -32)
	controls.ShowDraggingHandle:SetPoint("LEFT", panel, "LEFT", 24, 0)
	
	controls.ShowSolo = CreateCheckButton(objectName.."ShowSolo", panel, "Show Raid Frame when solo")
	controls.ShowSolo:SetPoint("TOP", controls.ShowDraggingHandle, "TOP", 0, -28)
	controls.ShowSolo:SetPoint("LEFT", panel, "LEFT", 24, 0)
	
	--controls.MirrorRow = CreateCheckButton(objectName.."MirrorRow", panel, "Flip Rows (Grow from Right to Left)")
	--controls.MirrorRow:SetPoint("TOP", controls.ShowSolo, "TOP", 0, -28)
	--controls.MirrorRow:SetPoint("LEFT", panel, "LEFT", 24, 0)
	
	-- Reset
	ResetButton = CreateFrame("Button", objectName.."ResetButton", panel, "UIPanelButtonTemplate2")
	ResetButton:SetPoint("TOP", controls.ShowSolo, "TOP", 0, -28)
	ResetButton:SetPoint("LEFT", panel, "LEFT", 24, 0)
	ResetButton:SetWidth(300)
	ResetButton:SetText("Reset Position")
	ResetButton:SetScript("OnClick", ResetPosition)
	
	-- Set Click for ALL Controls
	for i,v in pairs(controls) do
		v:SetScript("OnClick", GetPanelValues)
	end
	
	----------------
	-- Return a pointer to the whole thingy
	----------------
	InterfaceOptions_AddCategory(panel)
	return panel
end

CreateInterfacePanel("ShotGlassPanel", "Shot Glass")
local function OpenShotGlassConfigPanel()
	InterfaceOptionsFrame_OpenToCategory("Shot Glass")
end

SLASH_SHOTGLASS1 = '/shotglass'
SlashCmdList['SHOTGLASS'] = OpenShotGlassConfigPanel;


